@@ -16,6 +16,7 @@
 
 package org.apache.log4j;
 
+import org.apache.log4j.spi.LoggerFactory;
 import org.slf4j.spi.LocationAwareLogger;
 
 /**
@@ -31,7 +32,7 @@ public class Logger extends Category {
   
   private static final String LOGGER_FQCN = Logger.class.getName();
   
-  Logger(String name) {
+  protected Logger(String name) {
     super(name);
   }
 
@@ -39,6 +40,10 @@ public class Logger extends Category {
     return Log4jLoggerFactory.getLogger(name);
   }
 
+  public static Logger getLogger(String name, LoggerFactory loggerFactory) {
+    return Log4jLoggerFactory.getLogger(name,loggerFactory);
+  }
+
   public static Logger getLogger(Class clazz) {
     return getLogger(clazz.getName());
   }
